// ========================================================================
// gnubiff -- a mail notification program
// Copyright (c) 2000-2005 Nicolas Rougier
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// ========================================================================
//
// File          : $RCSfile: pop3.h,v $
// Revision      : $Revision: 1.5 $
// Revision date : $Date: 2005/03/29 11:57:32 $
// Author(s)     : Nicolas Rougier
// Short         : 
//
// This file is part of gnubiff.
//
// -*- mode:C++; tab-width:4; c-basic-offset:4; indent-tabs-mode:nil -*-
// ========================================================================

#ifndef __POP3_H__
#define __POP3_H__

#include "pop.h"

/**
 * Mailbox for the POP3 protocol. 
 */
class Pop3 : public Pop {

public:
	// ========================================================================
	//  base
	// ========================================================================	
	Pop3 (class Biff *biff);
	Pop3 (const Mailbox &other);
	~Pop3 (void);

	// ========================================================================
	//  main
	// ========================================================================	
	void connect (void) throw (pop_err);
};

#endif
